# ProgettoBIO

## How to use the no-code interface

Run the server with the following commands:

> export FLASK_APP=server

> python server.py

Then head over to the react client (https://github.com/Pier297/BioSearch)
and execute:

> npm start

## How to use pubmad pyp library

To perform installation run:

> pip install pubmad

Then check out the documentation to look at the available commands (https://pier297.github.io/ProgettoBIO/) or look at demo.ipynb notebook to get an overview of potential use of the commands.
